pub enum ShadowRootMode {
Open,
Closed,
}Expand description
The encapsulation mode of a shadow root.
Mirrors the ShadowRootMode enum from the DOM specification.
Variants
Open
Elements of the shadow root are accessible from JavaScript outside the
root (e.g. via Element.shadowRoot).
Closed
Elements of the shadow root are not accessible from JavaScript outside the root.