pub struct NodeFlags(/* private fields */);Implementations
Sourceimpl NodeFlags
impl NodeFlags
Sourcepub const IS_INLINE_ROOT: NodeFlags
pub const IS_INLINE_ROOT: NodeFlags
Whether the node is the root node of an Inline Formatting Context
Sourcepub const IS_TABLE_ROOT: NodeFlags
pub const IS_TABLE_ROOT: NodeFlags
Whether the node is the root node of an Table formatting context
Sourcepub const IS_IN_DOCUMENT: NodeFlags
pub const IS_IN_DOCUMENT: NodeFlags
Whether the node is “in the document” (~= has a parent and isn’t a template node)
Sourcepub const IS_PARSER_INERT_SCRIPT: NodeFlags
pub const IS_PARSER_INERT_SCRIPT: NodeFlags
Parser-created scripts remain inert after cloning or adoption.
Sourceimpl NodeFlags
impl NodeFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<NodeFlags>
pub const fn from_bits(bits: u32) -> Option<NodeFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> NodeFlags
pub const fn from_bits_truncate(bits: u32) -> NodeFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> NodeFlags
pub const fn from_bits_retain(bits: u32) -> NodeFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<NodeFlags>
pub fn from_name(name: &str) -> Option<NodeFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: NodeFlags) -> bool
pub const fn intersects(&self, other: NodeFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: NodeFlags) -> bool
pub const fn contains(&self, other: NodeFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: NodeFlags)
pub fn remove(&mut self, other: NodeFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: NodeFlags)
pub fn toggle(&mut self, other: NodeFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: NodeFlags, value: bool)
pub fn set(&mut self, other: NodeFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: NodeFlags) -> NodeFlags
pub const fn intersection(self, other: NodeFlags) -> NodeFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: NodeFlags) -> NodeFlags
pub const fn union(self, other: NodeFlags) -> NodeFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: NodeFlags) -> NodeFlags
pub const fn difference(self, other: NodeFlags) -> NodeFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: NodeFlags) -> NodeFlags
pub const fn symmetric_difference(self, other: NodeFlags) -> NodeFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> NodeFlags
pub const fn complement(self) -> NodeFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl NodeFlags
impl NodeFlags
Sourceimpl NodeFlags
impl NodeFlags
pub fn is_inline_root(&self) -> bool
pub fn is_table_root(&self) -> bool
pub fn is_in_document(&self) -> bool
pub fn reset_construction_flags(&mut self)