pub struct TextBrush {
pub id: NodeId,
pub text_node: Option<NodeId>,
}Expand description
Parley Brush type for Blitz which contains the Blitz node id
Fields
id: NodeIdThe node id for the span
text_node: Option<NodeId>The DOM text node supplying this run, separate from its styling element.