pub struct MouseEventButtons(/* private fields */);Expand description
The buttons property indicates which buttons are pressed on the mouse (or other input device) when a mouse event is triggered.
Implementations
Sourceimpl MouseEventButtons
impl MouseEventButtons
Sourcepub const None: MouseEventButtons
pub const None: MouseEventButtons
0: No button or un-initialized
Sourcepub const Primary: MouseEventButtons
pub const Primary: MouseEventButtons
1: Primary button (usually the left button)
Sourcepub const Secondary: MouseEventButtons
pub const Secondary: MouseEventButtons
2: Secondary button (usually the right button)
Sourcepub const Auxiliary: MouseEventButtons
pub const Auxiliary: MouseEventButtons
4: Auxiliary button (usually the mouse wheel button or middle button)
Sourcepub const Fourth: MouseEventButtons
pub const Fourth: MouseEventButtons
8: 4th button (typically the “Browser Back” button)
Sourcepub const Fifth: MouseEventButtons
pub const Fifth: MouseEventButtons
16: 5th button (typically the “Browser Forward” button)
Sourceimpl MouseEventButtons
impl MouseEventButtons
Sourcepub const fn empty() -> MouseEventButtons
pub const fn empty() -> MouseEventButtons
Get a flags value with all bits unset.
Sourcepub const fn all() -> MouseEventButtons
pub const fn all() -> MouseEventButtons
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<MouseEventButtons>
pub const fn from_bits(bits: u8) -> Option<MouseEventButtons>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> MouseEventButtons
pub const fn from_bits_truncate(bits: u8) -> MouseEventButtons
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> MouseEventButtons
pub const fn from_bits_retain(bits: u8) -> MouseEventButtons
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MouseEventButtons>
pub fn from_name(name: &str) -> Option<MouseEventButtons>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MouseEventButtons) -> bool
pub const fn intersects(&self, other: MouseEventButtons) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: MouseEventButtons) -> bool
pub const fn contains(&self, other: MouseEventButtons) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: MouseEventButtons)
pub fn insert(&mut self, other: MouseEventButtons)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: MouseEventButtons)
pub fn remove(&mut self, other: MouseEventButtons)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MouseEventButtons)
pub fn toggle(&mut self, other: MouseEventButtons)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: MouseEventButtons, value: bool)
pub fn set(&mut self, other: MouseEventButtons, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MouseEventButtons) -> MouseEventButtons
pub const fn intersection(self, other: MouseEventButtons) -> MouseEventButtons
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: MouseEventButtons) -> MouseEventButtons
pub const fn union(self, other: MouseEventButtons) -> MouseEventButtons
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: MouseEventButtons) -> MouseEventButtons
pub const fn difference(self, other: MouseEventButtons) -> MouseEventButtons
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: MouseEventButtons,
) -> MouseEventButtons
pub const fn symmetric_difference( self, other: MouseEventButtons, ) -> MouseEventButtons
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> MouseEventButtons
pub const fn complement(self) -> MouseEventButtons
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MouseEventButtons
impl MouseEventButtons
Sourcepub const fn iter(&self) -> Iter<MouseEventButtons> ⓘ
pub const fn iter(&self) -> Iter<MouseEventButtons> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MouseEventButtons> ⓘ
pub const fn iter_names(&self) -> IterNames<MouseEventButtons> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.