NetHandler

Trait NetHandler 

pub trait NetHandler:
    Send
    + Sync
    + 'static {
    // Required method
    fn bytes(self: Box<Self>, resolved_url: String, bytes: Bytes);
}
A type that parses raw bytes from a network request into a Data and then calls the NetCallack with the result.

Required Methods

fn bytes(self: Box<Self>, resolved_url: String, bytes: Bytes)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors