pub trait NetHandler:
Send
+ Sync
+ 'static {
// Required method
fn bytes(self: Box<Self>, resolved_url: String, bytes: Bytes);
}Expand description
A type that parses raw bytes from a network request into a Data and then calls the NetCallack with the result.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".